abacusai.forecasting_monitor_summary — AbacusAI documentation

# `abacusai.forecasting_monitor_summary`

## Module Contents

### Classes

`ForecastingMonitorSummary` | Forecasting Monitor Summary of the latest version of the data.

class abacusai.forecasting_monitor_summary.ForecastingMonitorSummary(client, predictionTimestampCol=None, predictionTargetCol=None, trainingTimestampCol=None, trainingTargetCol=None, predictionItemId=None, trainingItemId=None, forecastFrequency=None, trainingTargetAcrossTime={}, predictionTargetAcrossTime={}, actualsHistogram={}, predictionsHistogram={}, trainHistoryData={}, predictHistoryData={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Forecasting Monitor Summary of the latest version of the data.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - predictionTimestampCol (str) – Feature in the data that represents the timestamp column.

    - predictionTargetCol (str) – Feature in the data that represents the target.

    - trainingTimestampCol (str) – Feature in the data that represents the timestamp column.

    - trainingTargetCol (str) – Feature in the data that represents the target.

    - predictionItemId (str) – Feature in the data that represents the item id.

    - trainingItemId (str) – Feature in the data that represents the item id.

    - forecastFrequency (str) – Frequency of data, could be hourly, daily, weekly, monthly, quarterly or yearly.

    - trainingTargetAcrossTime (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across time

    - predictionTargetAcrossTime (ForecastingAnalysisGraphData) – Data showing average, p10, p90, median sales across time

    - actualsHistogram (ForecastingAnalysisGraphData) – Data showing actuals histogram

    - predictionsHistogram (ForecastingAnalysisGraphData) – Data showing predictions histogram

    - trainHistoryData (ForecastingAnalysisGraphData) – Data showing length of history distribution

    - predictHistoryData (ForecastingAnalysisGraphData) – Data showing length of history distribution

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict